# Public: Install and configure git from homebrew.
#
# Examples
#
#   include git
class git (
  $package                 = $git::package,
  $configdir               = $git::configdir,
  $credentialhelper        = $git::credentialhelper,
  $global_credentialhelper = $git::global_credentialhelper,
  $global_excludesfile     = $git::global_excludesfile,
) {
  package { $package: }

  file { $configdir:
    ensure => directory
  }

  if $credentialhelper {
    file { $credentialhelper:
      ensure => file
    }
  }

  if $global_credentialhelper {
    file { $global_credentialhelper:
      ensure  => link,
      target  => $credentialhelper,
      before  => Package[$package],
      require => File[$credentialhelper]
    }

    git::config::global{ 'credential.helper':
      value => $global_credentialhelper
    }
  }

  file { "${configdir}/gitignore":
    source  => 'puppet:///modules/git/gitignore',
    require => File[$configdir]
  }

  git::config::global{ 'core.excludesfile':
    value   => $global_excludesfile,
    require => File["${configdir}/gitignore"]
  }

  if $::gname {
    git::config::global{ 'user.name':
      value => $::gname
    }
  }

  if $::gemail {
    git::config::global{ 'user.email':
      value => $::gemail
    }
  }
}
